﻿using System;
using SqlSugar;
using Infrastructure.Attribute;
using ZR.Model;
using ZR.Repository;
using System.Linq;
using Infrastructure;
using ZR.Service.Business.IBusinessService.OutStore;
using ZR.Model.Dto.OutStore;
using ZR.Model.Models.OutStore;
using System.Collections.Generic;
using ZR.Model.Models.Statistics;

namespace ZR.Service.Business.OutStore
{
    /// <summary>
    /// 出库管理/出库记录表Service业务层处理
    ///
    /// @author admin
    /// @date 2023-04-18
    /// </summary>
    [AppService(ServiceType = typeof(IOutOutstoreRecordService), ServiceLifetime = LifeTime.Transient)]
    public class OutOutstoreRecordService : BaseService<OutOutstoreRecord>, IOutOutstoreRecordService
    {
        #region 业务逻辑代码

        /// <summary>
        /// 查询出库管理/出库记录表列表
        /// </summary>
        /// <param name="parm"></param>
        /// <returns></returns>
        public PagedInfo<OutOutstoreRecordDto> GetList(OutOutstoreRecordQueryDto parm, bool isPdaQuery = false)
        {
            //开始拼装查询条件
            var predicate = Expressionable.Create<OutOutstoreRecord>();
            if (parm.BeginTime != null && parm.EndTime != null)
            {
                parm.BeginTime = parm.BeginTime.Value.ToLocalTime();
                parm.EndTime = parm.EndTime.Value.ToLocalTime();
                predicate.And(it => it.CreateTime >= parm.BeginTime && it.CreateTime <= parm.EndTime);
            }
            predicate.AndIF(!string.IsNullOrEmpty(parm.OutSotreNo), it => it.OutSotreNo.Contains(parm.OutSotreNo));
            predicate.AndIF(!string.IsNullOrEmpty(parm.BomNo), it => it.BomNo.Contains(parm.BomNo));

            if (!isPdaQuery)
            {
                predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialCode), d => d.MaterialCode.Contains(parm.MaterialCode));
                predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialName), d => d.MaterialName.Contains(parm.MaterialName));
                predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialSpec), d => d.MaterialSpec.Contains(parm.MaterialSpec));
            }
            else
            {
                predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialCode), d => d.MaterialCode.Contains(parm.MaterialCode) || d.MaterialName.Contains(parm.MaterialCode) || d.MaterialSpec.Contains(parm.MaterialCode));
            }

            predicate.AndIF(!string.IsNullOrEmpty(parm.BnSnCode), it => it.BnSnCode.Contains(parm.BnSnCode));
            predicate.AndIF(!string.IsNullOrEmpty(parm.Category), it => it.Category == parm.Category);
            predicate.AndIF(!string.IsNullOrEmpty(parm.CreateBy), it => it.CreateBy.Contains(parm.CreateBy));
            predicate.AndIF(parm.KeyFlag != null, it => it.KeyFlag == parm.KeyFlag);
            predicate.AndIF(parm.Result != null, it => it.Result == parm.Result);
            //搜索条件查询语法参考Sqlsugar
            var response = Queryable()
                .Where(predicate.ToExpression())
                .ToPage<OutOutstoreRecord, OutOutstoreRecordDto>(parm);

            return response;
        }

        public List<OutOutstoreRecord> GetSelect(OutOutstoreRecordQueryDto parm)
        {
            //开始拼装查询条件
            var predicate = Expressionable.Create<OutOutstoreRecord>();
            if (parm.BeginTime != null && parm.EndTime != null)
            {
                parm.BeginTime = parm.BeginTime.Value.ToLocalTime();
                parm.EndTime = parm.EndTime.Value.ToLocalTime();
                predicate.And(it => it.CreateTime >= parm.BeginTime && it.CreateTime <= parm.EndTime);
            }
            predicate.AndIF(!string.IsNullOrEmpty(parm.OutSotreNo), it => it.OutSotreNo.Contains(parm.OutSotreNo));
            predicate.AndIF(!string.IsNullOrEmpty(parm.BomNo), it => it.BomNo.Contains(parm.BomNo));

            predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialCode), d => d.MaterialCode.Contains(parm.MaterialCode));
            predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialName), d => d.MaterialName.Contains(parm.MaterialName));
            predicate.AndIF(!string.IsNullOrEmpty(parm.MaterialSpec), d => d.MaterialSpec.Contains(parm.MaterialSpec));
            predicate.AndIF(!string.IsNullOrEmpty(parm.BnSnCode), it => it.BnSnCode.Contains(parm.BnSnCode));
            predicate.AndIF(!string.IsNullOrEmpty(parm.Category), it => it.Category == parm.Category);
            predicate.AndIF(!string.IsNullOrEmpty(parm.CreateBy), it => it.CreateBy.Contains(parm.CreateBy));
            predicate.AndIF(parm.KeyFlag != null, it => it.KeyFlag == parm.KeyFlag);
            predicate.AndIF(parm.Result != null, it => it.Result == parm.Result);
            //搜索条件查询语法参考Sqlsugar
            var response = Queryable()
                .Where(predicate.ToExpression())
                .ToList();

            return response;
        }
        public List<GroupByKey> GetDailyStatistics(DateTime BeginTime, DateTime EndTime)
        {
            //开始拼装查询条件
            var predicate = Expressionable.Create<OutOutstoreRecord>();
            predicate.And(d => d.CreateTime >= BeginTime && d.CreateTime <= EndTime);
            //搜索条件查询语法参考Sqlsugar
            var response = Queryable()
                .GroupBy(d => new { d.KeyFlag })
                .Where(predicate.ToExpression())
                .Select(d => new GroupByKey
                {
                    KeyFlag = d.KeyFlag,
                    SumQty = SqlFunc.AggregateSum(d.OutStoreQty),
                })
                .ToList();

            return response;
        }

        /// <summary>
        /// 添加出库管理/出库记录表
        /// </summary>
        /// <param name="model"></param>
        /// <returns></returns>
        public int AddOutOutstoreRecord(OutOutstoreRecord model)
        {
            return Add(model, true);
        }

        /// <summary>
        /// 修改出库管理/出库记录表
        /// </summary>
        /// <param name="model"></param>
        /// <returns></returns>
        public int UpdateOutOutstoreRecord(OutOutstoreRecord model)
        {
            //var response = Update(w => w.OutStoreId == model.OutStoreId, it => new OutOutstoreRecord()
            //{
            //    OutSotreNo = model.OutSotreNo,
            //    BomNo = model.BomNo,
            //    MaterialCode = model.MaterialCode,
            //    MaterialName = model.MaterialName,
            //    MaterialSpec = model.MaterialSpec,
            //    Category = model.Category,
            //    KeyFlag = model.KeyFlag,
            //    OutStoreQty = model.OutStoreQty,
            //    Result = model.Result,
            //    UpdateBy = model.UpdateBy,
            //    UpdateTime = model.UpdateTime,
            //    Remark = model.Remark,
            //    BnSnCode = model.BnSnCode,
            //});
            //return response;
            return Update(model, true);
        }

        /// <summary>
        /// 清空出库管理/出库记录表
        /// </summary>
        /// <returns></returns>
        public void TruncateOutOutstoreRecord()
        {
            Truncate();
        }
        #endregion
    }
}